Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Page
Library
Module
Module type
Parameter
Class
Class type
Interfaces.SETInterface for a finite set.
val is_empty : t -> boolIs the set empty?
val cardinal : t -> intThe cardinality of the set i.e. the number of its elements.
fold_left f start set
Fold the elements of the set set from left to right i.e. lexically ascending using the start value start for the accumulator and the folding function f where f is applied f accu element yielding a new accumulator value by consuming one element.
fold_left f start set
Fold the elements of the set set from right to left i.e. lexically descending using the start value start for the accumulator and the folding function f where f is applied f accu element yielding a new accumulator value by consuming one element.
val empty : tThe empty set.
add element set Add the element element to the set set. If the element is already in the set, then do nothing.